class TimeSpan(object,IComparable,IComparable[TimeSpan],IEquatable[TimeSpan],IFormattable):
 """
 Represents a time interval.

 

 TimeSpan(ticks: Int64)

 TimeSpan(hours: int,minutes: int,seconds: int)

 TimeSpan(days: int,hours: int,minutes: int,seconds: int)

 TimeSpan(days: int,hours: int,minutes: int,seconds: int,milliseconds: int)
 """
 def Add(self,ts):
  """
  Add(self: TimeSpan,ts: TimeSpan) -> TimeSpan

  

   Returns a new System.TimeSpan object whose value is the sum of the specified System.TimeSpan 

    object and this instance.

  

  

   ts: The time interval to add.

   Returns: A new object that represents the value of this instance plus the value of ts.
  """
  pass
 @staticmethod
 def Compare(t1,t2):
  """
  Compare(t1: TimeSpan,t2: TimeSpan) -> int

  

   Compares two System.TimeSpan values and returns an integer that indicates whether the first 

    value is shorter than,equal to,or longer than the second value.

  

  

   t1: The first time interval to compare.

   t2: The second time interval to compare.

   Returns: One of the following values.Value Description -1 t1 is shorter than t2. 0 t1 is equal to t2. 1 

    t1 is longer than t2.
  """
  pass
 def CompareTo(self,value):
  """
  CompareTo(self: TimeSpan,value: TimeSpan) -> int

  

   Compares this instance to a specified System.TimeSpan object and returns an integer that 

    indicates whether this instance is shorter than,equal to,or longer than the System.TimeSpan 

    object.

  

  

   value: An object to compare to this instance.

   Returns: A signed number indicating the relative values of this instance and value.Value Description A 

    negative integer This instance is shorter than value. Zero This instance is equal to value. A 

    positive integer This instance is longer than value.

  

  CompareTo(self: TimeSpan,value: object) -> int

  

   Compares this instance to a specified object and returns an integer that indicates whether this 

    instance is shorter than,equal to,or longer than the specified object.

  

  

   value: An object to compare,or null.

   Returns: One of the following values.Value Description -1 This instance is shorter than value. 0 This 

    instance is equal to value. 1 This instance is longer than value.-or- value is null.
  """
  pass
 def Duration(self):
  """
  Duration(self: TimeSpan) -> TimeSpan

  

   Returns a new System.TimeSpan object whose value is the absolute value of the current 

    System.TimeSpan object.

  

   Returns: A new object whose value is the absolute value of the current System.TimeSpan object.
  """
  pass
 def Equals(self,*__args):
  """
  Equals(t1: TimeSpan,t2: TimeSpan) -> bool

  

   Returns a value that indicates whether two specified instances of System.TimeSpan are equal.

  

   t1: The first time interval to compare.

   t2: The second time interval to compare.

   Returns: true if the values of t1 and t2 are equal; otherwise,false.

  Equals(self: TimeSpan,obj: TimeSpan) -> bool

  

   Returns a value indicating whether this instance is equal to a specified System.TimeSpan object.

  

   obj: An object to compare with this instance.

   Returns: true if obj represents the same time interval as this instance; otherwise,false.

  Equals(self: TimeSpan,value: object) -> bool

  

   Returns a value indicating whether this instance is equal to a specified object.

  

   value: An object to compare with this instance.

   Returns: true if value is a System.TimeSpan object that represents the same time interval as the current 

    System.TimeSpan structure; otherwise,false.
  """
  pass
 @staticmethod
 def FromDays(value):
  """
  FromDays(value: float) -> TimeSpan

  

   Returns a System.TimeSpan that represents a specified number of days,where the specification is 

    accurate to the nearest millisecond.

  

  

   value: A number of days,accurate to the nearest millisecond.

   Returns: An object that represents value.
  """
  pass
 @staticmethod
 def FromHours(value):
  """
  FromHours(value: float) -> TimeSpan

  

   Returns a System.TimeSpan that represents a specified number of hours,where the specification 

    is accurate to the nearest millisecond.

  

  

   value: A number of hours accurate to the nearest millisecond.

   Returns: An object that represents value.
  """
  pass
 @staticmethod
 def FromMilliseconds(value):
  """
  FromMilliseconds(value: float) -> TimeSpan

  

   Returns a System.TimeSpan that represents a specified number of milliseconds.

  

   value: A number of milliseconds.

   Returns: An object that represents value.
  """
  pass
 @staticmethod
 def FromMinutes(value):
  """
  FromMinutes(value: float) -> TimeSpan

  

   Returns a System.TimeSpan that represents a specified number of minutes,where the specification 

    is accurate to the nearest millisecond.

  

  

   value: A number of minutes,accurate to the nearest millisecond.

   Returns: An object that represents value.
  """
  pass
 @staticmethod
 def FromSeconds(value):
  """
  FromSeconds(value: float) -> TimeSpan

  

   Returns a System.TimeSpan that represents a specified number of seconds,where the specification 

    is accurate to the nearest millisecond.

  

  

   value: A number of seconds,accurate to the nearest millisecond.

   Returns: An object that represents value.
  """
  pass
 @staticmethod
 def FromTicks(value):
  """
  FromTicks(value: Int64) -> TimeSpan

  

   Returns a System.TimeSpan that represents a specified time,where the specification is in units 

    of ticks.

  

  

   value: A number of ticks that represent a time.

   Returns: An object that represents value.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: TimeSpan) -> int

  

   Returns a hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def Negate(self):
  """
  Negate(self: TimeSpan) -> TimeSpan

  

   Returns a new System.TimeSpan object whose value is the negated value of this instance.

   Returns: A new object with the same numeric value as this instance,but with the opposite sign.
  """
  pass
 @staticmethod
 def Parse(*__args):
  """
  Parse(input: str,formatProvider: IFormatProvider) -> TimeSpan

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent by using 

    the specified culture-specific format information.

  

  

   input: A string that specifies the time interval to convert.

   formatProvider: An object that supplies culture-specific formatting information.

   Returns: A time interval that corresponds to input,as specified by formatProvider.

  Parse(s: str) -> TimeSpan

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent.

  

   s: A string that specifies the time interval to convert.

   Returns: A time interval that corresponds to s.
  """
  pass
 @staticmethod
 def ParseExact(input,*__args):
  """
  ParseExact(input: str,format: str,formatProvider: IFormatProvider,styles: TimeSpanStyles) -> TimeSpan

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent by using 

    the specified format,culture-specific format information,and styles. The format of the string 

    representation must match the specified format exactly.

  

  

   input: A string that specifies the time interval to convert.

   format: A standard or custom format string that defines the required format of input.

   formatProvider: An object that provides culture-specific formatting information.

   styles: A bitwise combination of enumeration values that defines the style elements that may be present 

    in input.

  

   Returns: A time interval that corresponds to input,as specified by format,formatProvider,and styles.

  ParseExact(input: str,formats: Array[str],formatProvider: IFormatProvider,styles: TimeSpanStyles) -> TimeSpan

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent by using 

    the specified formats,culture-specific format information,and styles. The format of the string 

    representation must match one of the specified formats exactly.

  

  

   input: A string that specifies the time interval to convert.

   formats: A array of standard or custom format strings that define the required format of input.

   formatProvider: An object that provides culture-specific formatting information.

   styles: A bitwise combination of enumeration values that defines the style elements that may be present 

    in input.

  

   Returns: A time interval that corresponds to input,as specified by formats,formatProvider,and styles.

  ParseExact(input: str,format: str,formatProvider: IFormatProvider) -> TimeSpan

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent by using 

    the specified format and culture-specific format information. The format of the string 

    representation must match the specified format exactly.

  

  

   input: A string that specifies the time interval to convert.

   format: A standard or custom format string that defines the required format of input.

   formatProvider: An object that provides culture-specific formatting information.

   Returns: A time interval that corresponds to input,as specified by format and formatProvider.

  ParseExact(input: str,formats: Array[str],formatProvider: IFormatProvider) -> TimeSpan

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent by using 

    the specified array of format strings and culture-specific format information. The format of the 

    string representation must match one of the specified formats exactly.

  

  

   input: A string that specifies the time interval to convert.

   formats: A array of standard or custom format strings that defines the required format of input.

   formatProvider: An object that provides culture-specific formatting information.

   Returns: A time interval that corresponds to input,as specified by formats and formatProvider.
  """
  pass
 def Subtract(self,ts):
  """
  Subtract(self: TimeSpan,ts: TimeSpan) -> TimeSpan

  

   Returns a new System.TimeSpan object whose value is the difference between the specified 

    System.TimeSpan object and this instance.

  

  

   ts: The time interval to be subtracted.

   Returns: A new time interval whose value is the result of the value of this instance minus the value of 

    ts.
  """
  pass
 def ToString(self,format=None,formatProvider=None):
  """
  ToString(self: TimeSpan,format: str,formatProvider: IFormatProvider) -> str

  

   Converts the value of the current System.TimeSpan object to its equivalent string representation 

    by using the specified format and culture-specific formatting information.

  

  

   format: A standard or custom System.TimeSpan format string.

   formatProvider: An object that supplies culture-specific formatting information.

   Returns: The string representation of the current System.TimeSpan value,as specified by format and 

    formatProvider.

  

  ToString(self: TimeSpan,format: str) -> str

  

   Converts the value of the current System.TimeSpan object to its equivalent string representation 

    by using the specified format.

  

  

   format: A standard or custom System.TimeSpan format string.

   Returns: The string representation of the current System.TimeSpan value in the format specified by the 

    format parameter.

  

  ToString(self: TimeSpan) -> str

  

   Converts the value of the current System.TimeSpan object to its equivalent string representation.

   Returns: The string representation of the current System.TimeSpan value.
  """
  pass
 @staticmethod
 def TryParse(*__args):
  """
  TryParse(input: str,formatProvider: IFormatProvider) -> (bool,TimeSpan)

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent by using 

    the specified culture-specific formatting information,and returns a value that indicates 

    whether the conversion succeeded.

  

  

   input: A string that specifies the time interval to convert.

   formatProvider: An object that supplies culture-specific formatting information.

   Returns: true if input was converted successfully; otherwise,false. This operation returns false if the 

    input parameter is null or System.String.Empty,has an invalid format,represents a time 

    interval that is less than System.TimeSpan.MinValue or greater than System.TimeSpan.MaxValue,or 

    has at least one days,hours,minutes,or seconds component outside its valid range.

  

  TryParse(s: str) -> (bool,TimeSpan)

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent and 

    returns a value that indicates whether the conversion succeeded.

  

  

   s: A string that specifies the time interval to convert.

   Returns: true if s was converted successfully; otherwise,false. This operation returns false if the s 

    parameter is null or System.String.Empty,has an invalid format,represents a time interval that 

    is less than System.TimeSpan.MinValue or greater than System.TimeSpan.MaxValue,or has at least 

    one days,hours,minutes,or seconds component outside its valid range.
  """
  pass
 @staticmethod
 def TryParseExact(input,*__args):
  """
  TryParseExact(input: str,format: str,formatProvider: IFormatProvider,styles: TimeSpanStyles) -> (bool,TimeSpan)

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent by using 

    the specified format,culture-specific format information,and styles,and returns a value that 

    indicates whether the conversion succeeded. The format of the string representation must match 

    the specified format exactly.

  

  

   input: A string that specifies the time interval to convert.

   format: A standard or custom format string that defines the required format of input.

   formatProvider: An object that provides culture-specific formatting information.

   styles: One or more enumeration values that indicate the style of input.

   Returns: true if input was converted successfully; otherwise,false.

  TryParseExact(input: str,formats: Array[str],formatProvider: IFormatProvider,styles: TimeSpanStyles) -> (bool,TimeSpan)

  

   Converts the specified string representation of a time interval to its System.TimeSpan 

    equivalent by using the specified formats,culture-specific format information,and styles,and 

    returns a value that indicates whether the conversion succeeded. The format of the string 

    representation must match one of the specified formats exactly.

  

  

   input: A string that specifies the time interval to convert.

   formats: A array of standard or custom format strings that define the acceptable formats of input.

   formatProvider: An object that supplies culture-specific formatting information.

   styles: One or more enumeration values that indicate the style of input.

   Returns: true if input was converted successfully; otherwise,false.

  TryParseExact(input: str,format: str,formatProvider: IFormatProvider) -> (bool,TimeSpan)

  

   Converts the string representation of a time interval to its System.TimeSpan equivalent by using 

    the specified format and culture-specific format information,and returns a value that indicates 

    whether the conversion succeeded. The format of the string representation must match the 

    specified format exactly.

  

  

   input: A string that specifies the time interval to convert.

   format: A standard or custom format string that defines the required format of input.

   formatProvider: An object that supplies culture-specific formatting information.

   Returns: true if input was converted successfully; otherwise,false.

  TryParseExact(input: str,formats: Array[str],formatProvider: IFormatProvider) -> (bool,TimeSpan)

  

   Converts the specified string representation of a time interval to its System.TimeSpan 

    equivalent by using the specified formats and culture-specific format information,and returns a 

    value that indicates whether the conversion succeeded. The format of the string representation 

    must match one of the specified formats exactly.

  

  

   input: A string that specifies the time interval to convert.

   formats: A array of standard or custom format strings that define the acceptable formats of input.

   formatProvider: An object that provides culture-specific formatting information.

   Returns: true if input was converted successfully; otherwise,false.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __cmp__(self,*args):
  """ x.__cmp__(y) <==> cmp(x,y) """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __neg__(self,*args):
  """ x.__neg__() <==> -x """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,ticks: Int64)

  __new__(cls: type,hours: int,minutes: int,seconds: int)

  __new__(cls: type,days: int,hours: int,minutes: int,seconds: int)

  __new__(cls: type,days: int,hours: int,minutes: int,seconds: int,milliseconds: int)

  __new__[TimeSpan]() -> TimeSpan
  """
  pass
 def __ne__(self,*args):
  pass
 def __pos__(self,*args):
  """
  __pos__(t: TimeSpan) -> TimeSpan

  

   Returns the specified instance of System.TimeSpan.

  

   t: The time interval to return.

   Returns: The time interval specified by t.
  """
  pass
 def __radd__(self,*args):
  """
  __radd__(t1: TimeSpan,t2: TimeSpan) -> TimeSpan

  

   Adds two specified System.TimeSpan instances.

  

   t1: The first time interval to add.

   t2: The second time interval to add.

   Returns: An object whose value is the sum of the values of t1 and t2.
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __rsub__(self,*args):
  """
  __rsub__(t1: TimeSpan,t2: TimeSpan) -> TimeSpan

  

   Subtracts a specified System.TimeSpan from another specified System.TimeSpan.

  

   t1: The minuend.

   t2: The subtrahend.

   Returns: An object whose value is the result of the value of t1 minus the value of t2.
  """
  pass
 def __str__(self,*args):
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-y """
  pass
 Days=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the days component of the time interval represented by the current System.TimeSpan structure.



Get: Days(self: TimeSpan) -> int



"""

 Hours=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the hours component of the time interval represented by the current System.TimeSpan structure.



Get: Hours(self: TimeSpan) -> int



"""

 Milliseconds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the milliseconds component of the time interval represented by the current System.TimeSpan structure.



Get: Milliseconds(self: TimeSpan) -> int



"""

 Minutes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the minutes component of the time interval represented by the current System.TimeSpan structure.



Get: Minutes(self: TimeSpan) -> int



"""

 Seconds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the seconds component of the time interval represented by the current System.TimeSpan structure.



Get: Seconds(self: TimeSpan) -> int



"""

 Ticks=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of ticks that represent the value of the current System.TimeSpan structure.



Get: Ticks(self: TimeSpan) -> Int64



"""

 TotalDays=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value of the current System.TimeSpan structure expressed in whole and fractional days.



Get: TotalDays(self: TimeSpan) -> float



"""

 TotalHours=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value of the current System.TimeSpan structure expressed in whole and fractional hours.



Get: TotalHours(self: TimeSpan) -> float



"""

 TotalMilliseconds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value of the current System.TimeSpan structure expressed in whole and fractional milliseconds.



Get: TotalMilliseconds(self: TimeSpan) -> float



"""

 TotalMinutes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value of the current System.TimeSpan structure expressed in whole and fractional minutes.



Get: TotalMinutes(self: TimeSpan) -> float



"""

 TotalSeconds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value of the current System.TimeSpan structure expressed in whole and fractional seconds.



Get: TotalSeconds(self: TimeSpan) -> float



"""


 MaxValue=None
 MinValue=None
 TicksPerDay=None
 TicksPerHour=None
 TicksPerMillisecond=None
 TicksPerMinute=None
 TicksPerSecond=None
 Zero=None




class PropertyValueChangedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.PropertyGrid.PropertyValueChanged event of a System.Windows.Forms.PropertyGrid.

 

 PropertyValueChangedEventArgs(changedItem: GridItem,oldValue: object)
 """
 @staticmethod
 def __new__(self,changedItem,oldValue):
  """ __new__(cls: type,changedItem: GridItem,oldValue: object) """
  pass
 ChangedItem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.GridItem that was changed.



Get: ChangedItem(self: PropertyValueChangedEventArgs) -> GridItem



"""

 OldValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """The value of the grid item before it was changed.



Get: OldValue(self: PropertyValueChangedEventArgs) -> object



"""





# encoding: utf-8
# module System.Windows.Converters calls itself Converters
# from WindowsBase,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Int32RectValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Int32Rect.

 

 Int32RectValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Int32RectValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Int32Rect.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Int32RectValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Int32Rect can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Int32RectValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Int32Rect.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Int32Rect based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Int32RectValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Int32Rect to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Int32Rect.
  """
  pass

class PointValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Point.

 

 PointValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: PointValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Point.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: PointValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Point can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: PointValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Point.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Point based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: PointValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Point to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Point.
  """
  pass

class RectValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Rect.

 

 RectValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: RectValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Rect.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: RectValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Rect can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: RectValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Rect.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Rect based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: RectValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Rect to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Rect.
  """
  pass

class SizeValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Size.

 

 SizeValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: SizeValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Size.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: SizeValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Size can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: SizeValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Size.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Size based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: SizeValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Size to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Size.
  """
  pass

class VectorValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Vector.

 

 VectorValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: VectorValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Vector.

  

  

   value: String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: Always returns true.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: VectorValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.Windows.Vector can be converted to a System.String.

  

   value: The object to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: VectorValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Vector.

  

   value: The string to convert.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Vector based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: VectorValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Vector to a System.String.

  

   value: The object to convert into a string.

   context: Context information that is used for conversion.

   Returns: A string representation of the specified System.Windows.Vector.
  """
  pass




class PreserveSigAttribute(Attribute,_Attribute):
 """
 Indicates that the HRESULT or retval signature transformation that takes place during COM interop calls should be suppressed.

 

 PreserveSigAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class ExternalException(SystemException,ISerializable,_Exception):
 """
 The base exception type for all COM interop exceptions and structured exception handling (SEH) exceptions.

 

 ExternalException()

 ExternalException(message: str)

 ExternalException(message: str,inner: Exception)

 ExternalException(message: str,errorCode: int)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def ToString(self):
  """
  ToString(self: ExternalException) -> str

  

   Returns a string that contains the HRESULT of the error.

   Returns: A string that represents the HRESULT.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,inner: Exception)

  __new__(cls: type,message: str,errorCode: int)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 ErrorCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the HRESULT of the error.



Get: ErrorCode(self: ExternalException) -> int



"""





class GroupStyle(object,INotifyPropertyChanged):
 """
 Defines how you want the group to look at each level.

 

 GroupStyle()
 """
 def add_PropertyChanged(self,*args):
  """ add_PropertyChanged(self: GroupStyle,value: PropertyChangedEventHandler) """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: GroupStyle,e: PropertyChangedEventArgs)

   Raises the System.Windows.Controls.GroupStyle.PropertyChanged event using the provided arguments.

  

   e: Arguments of the event being raised.
  """
  pass
 def remove_PropertyChanged(self,*args):
  """ remove_PropertyChanged(self: GroupStyle,value: PropertyChangedEventHandler) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 AlternationCount=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of alternating System.Windows.Controls.GroupItem objects.



Get: AlternationCount(self: GroupStyle) -> int



Set: AlternationCount(self: GroupStyle)=value

"""

 ContainerStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the style that is applied to the System.Windows.Controls.GroupItem generated for each item.



Get: ContainerStyle(self: GroupStyle) -> Style



Set: ContainerStyle(self: GroupStyle)=value

"""

 ContainerStyleSelector=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Enables the application writer to provide custom selection logic for a style to apply to each generated System.Windows.Controls.GroupItem.



Get: ContainerStyleSelector(self: GroupStyle) -> StyleSelector



Set: ContainerStyleSelector(self: GroupStyle)=value

"""

 HeaderStringFormat=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a composite string that specifies how to format the header if it is displayed as a string.



Get: HeaderStringFormat(self: GroupStyle) -> str



Set: HeaderStringFormat(self: GroupStyle)=value

"""

 HeaderTemplate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the template that is used to display the group header.



Get: HeaderTemplate(self: GroupStyle) -> DataTemplate



Set: HeaderTemplate(self: GroupStyle)=value

"""

 HeaderTemplateSelector=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Enables the application writer to provide custom selection logic for a template that is used to display the group header.



Get: HeaderTemplateSelector(self: GroupStyle) -> DataTemplateSelector



Set: HeaderTemplateSelector(self: GroupStyle)=value

"""

 HidesIfEmpty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether items corresponding to empty groups should be displayed.



Get: HidesIfEmpty(self: GroupStyle) -> bool



Set: HidesIfEmpty(self: GroupStyle)=value

"""

 Panel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a template that creates the panel used to layout the items.



Get: Panel(self: GroupStyle) -> ItemsPanelTemplate



Set: Panel(self: GroupStyle)=value

"""


 Default=None
 DefaultGroupPanel=None




class TypeInitializationException(SystemException,ISerializable,_Exception):
 """
 The exception that is thrown as a wrapper around the exception thrown by the class initializer. This class cannot be inherited.

 

 TypeInitializationException(fullTypeName: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: TypeInitializationException,info: SerializationInfo,context: StreamingContext)

   Sets the System.Runtime.Serialization.SerializationInfo object with the type name and additional 

    exception information.

  

  

   info: The System.Runtime.Serialization.SerializationInfo that holds the serialized object data about 

    the exception being thrown.

  

   context: The System.Runtime.Serialization.StreamingContext that contains contextual information about the 

    source or destination.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,fullTypeName,innerException):
  """ __new__(cls: type,fullTypeName: str,innerException: Exception) """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 TypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the fully qualified name of the type that fails to initialize.



Get: TypeName(self: TypeInitializationException) -> str



"""





class SystemPens(object):
 """ Each property of the System.Drawing.SystemPens class is a System.Drawing.Pen that is the color of a Windows display element and that has a width of 1 pixel. """
 @staticmethod
 def FromSystemColor(c):
  """
  FromSystemColor(c: Color) -> Pen

  

   Creates a System.Drawing.Pen from the specified System.Drawing.Color.

  

   c: The System.Drawing.Color for the new System.Drawing.Pen.

   Returns: The System.Drawing.Pen this method creates.
  """
  pass
 ActiveBorder=None
 ActiveCaption=None
 ActiveCaptionText=None
 AppWorkspace=None
 ButtonFace=None
 ButtonHighlight=None
 ButtonShadow=None
 Control=None
 ControlDark=None
 ControlDarkDark=None
 ControlLight=None
 ControlLightLight=None
 ControlText=None
 Desktop=None
 GradientActiveCaption=None
 GradientInactiveCaption=None
 GrayText=None
 Highlight=None
 HighlightText=None
 HotTrack=None
 InactiveBorder=None
 InactiveCaption=None
 InactiveCaptionText=None
 Info=None
 InfoText=None
 Menu=None
 MenuBar=None
 MenuHighlight=None
 MenuText=None
 ScrollBar=None
 Window=None
 WindowFrame=None
 WindowText=None




class ClockGroup(Clock):
 """ An assemblage of System.Windows.Media.Animation.Clock types with behavior based off of a System.Windows.Media.Animation.TimelineGroup. """
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """ __new__(cls: type,timelineGroup: TimelineGroup) """
  pass
 Children=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the children collection of this System.Windows.Media.Animation.ClockGroup.



Get: Children(self: ClockGroup) -> ClockCollection



"""

 CurrentGlobalTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current global time,as established by the WPF timing system.



"""

 Timeline=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Media.Animation.TimelineGroup object that dictates the behavior of this System.Windows.Media.Animation.ClockGroup instance.



Get: Timeline(self: ClockGroup) -> TimelineGroup



"""





class VARFLAGS(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.VARFLAGS instead.

 

 enum (flags) VARFLAGS,values: VARFLAG_FBINDABLE (4),VARFLAG_FDEFAULTBIND (32),VARFLAG_FDEFAULTCOLLELEM (256),VARFLAG_FDISPLAYBIND (16),VARFLAG_FHIDDEN (64),VARFLAG_FIMMEDIATEBIND (4096),VARFLAG_FNONBROWSABLE (1024),VARFLAG_FREADONLY (1),VARFLAG_FREPLACEABLE (2048),VARFLAG_FREQUESTEDIT (8),VARFLAG_FRESTRICTED (128),VARFLAG_FSOURCE (2),VARFLAG_FUIDEFAULT (512)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 value__=None
 VARFLAG_FBINDABLE=None
 VARFLAG_FDEFAULTBIND=None
 VARFLAG_FDEFAULTCOLLELEM=None
 VARFLAG_FDISPLAYBIND=None
 VARFLAG_FHIDDEN=None
 VARFLAG_FIMMEDIATEBIND=None
 VARFLAG_FNONBROWSABLE=None
 VARFLAG_FREADONLY=None
 VARFLAG_FREPLACEABLE=None
 VARFLAG_FREQUESTEDIT=None
 VARFLAG_FRESTRICTED=None
 VARFLAG_FSOURCE=None
 VARFLAG_FUIDEFAULT=None




class PageSetupDialog(CommonDialog,IComponent,IDisposable):
 """
 Enables users to change page-related print settings,including margins and paper orientation. This class cannot be inherited.

 

 PageSetupDialog()
 """
 def Dispose(self):
  """
  Dispose(self: Component,disposing: bool)

   Releases the unmanaged resources used by the System.ComponentModel.Component and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def HookProc(self,*args):
  """
  HookProc(self: CommonDialog,hWnd: IntPtr,msg: int,wparam: IntPtr,lparam: IntPtr) -> IntPtr

  

   Defines the common dialog box hook procedure that is overridden to add specific functionality to 

    a common dialog box.

  

  

   hWnd: The handle to the dialog box window.

   msg: The message being received.

   wparam: Additional information about the message.

   lparam: Additional information about the message.

   Returns: A zero value if the default dialog box procedure processes the message; a nonzero value if the 

    default dialog box procedure ignores the message.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnHelpRequest(self,*args):
  """
  OnHelpRequest(self: CommonDialog,e: EventArgs)

   Raises the System.Windows.Forms.CommonDialog.HelpRequest event.

  

   e: An System.Windows.Forms.HelpEventArgs that provides the event data.
  """
  pass
 def OwnerWndProc(self,*args):
  """
  OwnerWndProc(self: CommonDialog,hWnd: IntPtr,msg: int,wparam: IntPtr,lparam: IntPtr) -> IntPtr

  

   Defines the owner window procedure that is overridden to add specific functionality to a common 

    dialog box.

  

  

   hWnd: The window handle of the message to send.

   msg: The Win32 message to send.

   wparam: The wparam to send with the message.

   lparam: The lparam to send with the message.

   Returns: The result of the message processing,which is dependent on the message sent.
  """
  pass
 def Reset(self):
  """
  Reset(self: PageSetupDialog)

   Resets all options to their default values.
  """
  pass
 def RunDialog(self,*args):
  """ RunDialog(self: PageSetupDialog,hwndOwner: IntPtr) -> bool """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 AllowMargins=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the margins section of the dialog box is enabled.



Get: AllowMargins(self: PageSetupDialog) -> bool



Set: AllowMargins(self: PageSetupDialog)=value

"""

 AllowOrientation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the orientation section of the dialog box (landscape versus portrait) is enabled.



Get: AllowOrientation(self: PageSetupDialog) -> bool



Set: AllowOrientation(self: PageSetupDialog)=value

"""

 AllowPaper=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the paper section of the dialog box (paper size and paper source) is enabled.



Get: AllowPaper(self: PageSetupDialog) -> bool



Set: AllowPaper(self: PageSetupDialog)=value

"""

 AllowPrinter=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the Printer button is enabled.



Get: AllowPrinter(self: PageSetupDialog) -> bool



Set: AllowPrinter(self: PageSetupDialog)=value

"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Document=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating the System.Drawing.Printing.PrintDocument to get page settings from.



Get: Document(self: PageSetupDialog) -> PrintDocument



Set: Document(self: PageSetupDialog)=value

"""

 EnableMetric=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the margin settings,when displayed in millimeters,should be automatically converted to and from hundredths of an inch.



Get: EnableMetric(self: PageSetupDialog) -> bool



Set: EnableMetric(self: PageSetupDialog)=value

"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 MinMargins=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating the minimum margins,in hundredths of an inch,the user is allowed to select.



Get: MinMargins(self: PageSetupDialog) -> Margins



Set: MinMargins(self: PageSetupDialog)=value

"""

 PageSettings=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating the page settings to modify.



Get: PageSettings(self: PageSetupDialog) -> PageSettings



Set: PageSettings(self: PageSetupDialog)=value

"""

 PrinterSettings=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the printer settings that are modified when the user clicks the Printer button in the dialog.



Get: PrinterSettings(self: PageSetupDialog) -> PrinterSettings



Set: PrinterSettings(self: PageSetupDialog)=value

"""

 ShowHelp=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the Help button is visible.



Get: ShowHelp(self: PageSetupDialog) -> bool



Set: ShowHelp(self: PageSetupDialog)=value

"""

 ShowNetwork=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the Network button is visible.



Get: ShowNetwork(self: PageSetupDialog) -> bool



Set: ShowNetwork(self: PageSetupDialog)=value

"""





class IPEndPoint(EndPoint):
 """
 Represents a network endpoint as an IP address and a port number.

 

 IPEndPoint(address: Int64,port: int)

 IPEndPoint(address: IPAddress,port: int)
 """
 def Create(self,socketAddress):
  """
  Create(self: IPEndPoint,socketAddress: SocketAddress) -> EndPoint

  

   Creates an endpoint from a socket address.

  

   socketAddress: The System.Net.SocketAddress to use for the endpoint.

   Returns: An System.Net.EndPoint instance using the specified socket address.
  """
  pass
 def Equals(self,comparand):
  """
  Equals(self: IPEndPoint,comparand: object) -> bool

  

   Determines whether the specified System.Object is equal to the current System.Net.IPEndPoint 

    instance.

  

  

   comparand: The specified System.Object to compare with the current System.Net.IPEndPoint instance.

   Returns: true if the specified System.Object is equal to the current System.Object; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: IPEndPoint) -> int

  

   Returns a hash value for a System.Net.IPEndPoint instance.

   Returns: An integer hash value.
  """
  pass
 def Serialize(self):
  """
  Serialize(self: IPEndPoint) -> SocketAddress

  

   Serializes endpoint information into a System.Net.SocketAddress instance.

   Returns: A System.Net.SocketAddress instance containing the socket address for the endpoint.
  """
  pass
 def ToString(self):
  """
  ToString(self: IPEndPoint) -> str

  

   Returns the IP address and port number of the specified endpoint.

   Returns: A string containing the IP address and the port number of the specified endpoint (for example,

    192.168.1.2:80).
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,address,port):
  """
  __new__(cls: type,address: Int64,port: int)

  __new__(cls: type,address: IPAddress,port: int)
  """
  pass
 def __ne__(self,*args):
  pass
 Address=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the IP address of the endpoint.



Get: Address(self: IPEndPoint) -> IPAddress



Set: Address(self: IPEndPoint)=value

"""

 AddressFamily=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Internet Protocol (IP) address family.



Get: AddressFamily(self: IPEndPoint) -> AddressFamily



"""

 Port=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the port number of the endpoint.



Get: Port(self: IPEndPoint) -> int



Set: Port(self: IPEndPoint)=value

"""


 MaxPort=65535
 MinPort=0




class InstanceDataCollection(DictionaryBase,IDictionary,ICollection,IEnumerable):
 """
 Provides a strongly typed collection of System.Diagnostics.InstanceData objects.

 

 InstanceDataCollection(counterName: str)
 """
 def Contains(self,instanceName):
  """
  Contains(self: InstanceDataCollection,instanceName: str) -> bool

  

   Determines whether a performance instance with a specified name (identified by one of the 

    indexed System.Diagnostics.InstanceData objects) exists in the collection.

  

  

   instanceName: The name of the instance to find in this collection.

   Returns: true if the instance exists in the collection; otherwise,false.
  """
  pass
 def CopyTo(self,*__args):
  """
  CopyTo(self: InstanceDataCollection,instances: Array[InstanceData],index: int)

   Copies the items in the collection to the specified one-dimensional array at the specified index.

  

   instances: The one-dimensional System.Array that is the destination of the values copied from the 

    collection.

  

   index: The zero-based index value at which to add the new instances.
  """
  pass
 def OnClear(self,*args):
  """
  OnClear(self: DictionaryBase)

   Performs additional custom processes before clearing the contents of the 

    System.Collections.DictionaryBase instance.
  """
  pass
 def OnClearComplete(self,*args):
  """
  OnClearComplete(self: DictionaryBase)

   Performs additional custom processes after clearing the contents of the 

    System.Collections.DictionaryBase instance.
  """
  pass
 def OnGet(self,*args):
  """
  OnGet(self: DictionaryBase,key: object,currentValue: object) -> object

  

   Gets the element with the specified key and value in the System.Collections.DictionaryBase 

    instance.

  

  

   key: The key of the element to get.

   currentValue: The current value of the element associated with key.

   Returns: An System.Object containing the element with the specified key and value.
  """
  pass
 def OnInsert(self,*args):
  """
  OnInsert(self: DictionaryBase,key: object,value: object)

   Performs additional custom processes before inserting a new element into the 

    System.Collections.DictionaryBase instance.

  

  

   key: The key of the element to insert.

   value: The value of the element to insert.
  """
  pass
 def OnInsertComplete(self,*args):
  """
  OnInsertComplete(self: DictionaryBase,key: object,value: object)

   Performs additional custom processes after inserting a new element into the 

    System.Collections.DictionaryBase instance.

  

  

   key: The key of the element to insert.

   value: The value of the element to insert.
  """
  pass
 def OnRemove(self,*args):
  """
  OnRemove(self: DictionaryBase,key: object,value: object)

   Performs additional custom processes before removing an element from the 

    System.Collections.DictionaryBase instance.

  

  

   key: The key of the element to remove.

   value: The value of the element to remove.
  """
  pass
 def OnRemoveComplete(self,*args):
  """
  OnRemoveComplete(self: DictionaryBase,key: object,value: object)

   Performs additional custom processes after removing an element from the 

    System.Collections.DictionaryBase instance.

  

  

   key: The key of the element to remove.

   value: The value of the element to remove.
  """
  pass
 def OnSet(self,*args):
  """
  OnSet(self: DictionaryBase,key: object,oldValue: object,newValue: object)

   Performs additional custom processes before setting a value in the 

    System.Collections.DictionaryBase instance.

  

  

   key: The key of the element to locate.

   oldValue: The old value of the element associated with key.

   newValue: The new value of the element associated with key.
  """
  pass
 def OnSetComplete(self,*args):
  """
  OnSetComplete(self: DictionaryBase,key: object,oldValue: object,newValue: object)

   Performs additional custom processes after setting a value in the 

    System.Collections.DictionaryBase instance.

  

  

   key: The key of the element to locate.

   oldValue: The old value of the element associated with key.

   newValue: The new value of the element associated with key.
  """
  pass
 def OnValidate(self,*args):
  """
  OnValidate(self: DictionaryBase,key: object,value: object)

   Performs additional custom processes when validating the element with the specified key and 

    value.

  

  

   key: The key of the element to validate.

   value: The value of the element to validate.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,counterName):
  """ __new__(cls: type,counterName: str) """
  pass
 CounterName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the performance counter whose instance data you want to get.



Get: CounterName(self: InstanceDataCollection) -> str



"""

 Dictionary=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of elements contained in the System.Collections.DictionaryBase instance.



"""

 InnerHashtable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of elements contained in the System.Collections.DictionaryBase instance.



"""

 Keys=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the object and counter registry keys for the objects associated with this instance data.



Get: Keys(self: InstanceDataCollection) -> ICollection



"""

 Values=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the raw counter values that comprise the instance data for the counter.



Get: Values(self: InstanceDataCollection) -> ICollection



"""





class ICustomTypeDescriptor:
 """ Provides an interface that supplies dynamic custom type information for an object. """
 def GetAttributes(self):
  """
  GetAttributes(self: ICustomTypeDescriptor) -> AttributeCollection

  

   Returns a collection of custom attributes for this instance of a component.

   Returns: An System.ComponentModel.AttributeCollection containing the attributes for this object.
  """
  pass
 def GetClassName(self):
  """
  GetClassName(self: ICustomTypeDescriptor) -> str

  

   Returns the class name of this instance of a component.

   Returns: The class name of the object,or null if the class does not have a name.
  """
  pass
 def GetComponentName(self):
  """
  GetComponentName(self: ICustomTypeDescriptor) -> str

  

   Returns the name of this instance of a component.

   Returns: The name of the object,or null if the object does not have a name.
  """
  pass
 def GetConverter(self):
  """
  GetConverter(self: ICustomTypeDescriptor) -> TypeConverter

  

   Returns a type converter for this instance of a component.

   Returns: A System.ComponentModel.TypeConverter that is the converter for this object,or null if there is 

    no System.ComponentModel.TypeConverter for this object.
  """
  pass
 def GetDefaultEvent(self):
  """
  GetDefaultEvent(self: ICustomTypeDescriptor) -> EventDescriptor

  

   Returns the default event for this instance of a component.

   Returns: An System.ComponentModel.EventDescriptor that represents the default event for this object,or 

    null if this object does not have events.
  """
  pass
 def GetDefaultProperty(self):
  """
  GetDefaultProperty(self: ICustomTypeDescriptor) -> PropertyDescriptor

  

   Returns the default property for this instance of a component.

   Returns: A System.ComponentModel.PropertyDescriptor that represents the default property for this object,

    or null if this object does not have properties.
  """
  pass
 def GetEditor(self,editorBaseType):
  """
  GetEditor(self: ICustomTypeDescriptor,editorBaseType: Type) -> object

  

   Returns an editor of the specified type for this instance of a component.

  

   editorBaseType: A System.Type that represents the editor for this object.

   Returns: An System.Object of the specified type that is the editor for this object,or null if the editor 

    cannot be found.
  """
  pass
 def GetEvents(self,attributes=None):
  """
  GetEvents(self: ICustomTypeDescriptor,attributes: Array[Attribute]) -> EventDescriptorCollection

  

   Returns the events for this instance of a component using the specified attribute array as a 

    filter.

  

  

   attributes: An array of type System.Attribute that is used as a filter.

   Returns: An System.ComponentModel.EventDescriptorCollection that represents the filtered events for this 

    component instance.

  

  GetEvents(self: ICustomTypeDescriptor) -> EventDescriptorCollection

  

   Returns the events for this instance of a component.

   Returns: An System.ComponentModel.EventDescriptorCollection that represents the events for this component 

    instance.
  """
  pass
 def GetProperties(self,attributes=None):
  """
  GetProperties(self: ICustomTypeDescriptor,attributes: Array[Attribute]) -> PropertyDescriptorCollection

  

   Returns the properties for this instance of a component using the attribute array as a filter.

  

   attributes: An array of type System.Attribute that is used as a filter.

   Returns: A System.ComponentModel.PropertyDescriptorCollection that represents the filtered properties for 

    this component instance.

  

  GetProperties(self: ICustomTypeDescriptor) -> PropertyDescriptorCollection

  

   Returns the properties for this instance of a component.

   Returns: A System.ComponentModel.PropertyDescriptorCollection that represents the properties for this 

    component instance.
  """
  pass
 def GetPropertyOwner(self,pd):
  """
  GetPropertyOwner(self: ICustomTypeDescriptor,pd: PropertyDescriptor) -> object

  

   Returns an object that contains the property described by the specified property descriptor.

  

   pd: A System.ComponentModel.PropertyDescriptor that represents the property whose owner is to be 

    found.

  

   Returns: An System.Object that represents the owner of the specified property.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class DebuggerStepperBoundaryAttribute(Attribute,_Attribute):
 """
 Indicates the code following the attribute is to be executed in run,not step,mode.

 

 DebuggerStepperBoundaryAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __reduce_ex__(self,*args):
  pass



# encoding: utf-8
# module System.Windows calls itself Windows
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# no classes
# variables with complex values




class ColorConverter(TypeConverter):
 """
 Converts colors from one data type to another. Access this class through the System.ComponentModel.TypeDescriptor.

 

 ColorConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: ColorConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Determines if this converter can convert an object in the given source type to the native type 

    of the converter.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context. You can use this 

    object to get additional information about the environment from which this converter is being 

    invoked.

  

   sourceType: The type from which you want to convert.

   Returns: true if this object can perform the conversion; otherwise,false.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: ColorConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Returns a value indicating whether this converter can convert an object to the given destination 

    type using the context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   destinationType: A System.Type that represents the type to which you want to convert.

   Returns: true if this converter can perform the operation; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: ColorConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   Converts the given object to the converter's native type.

  

   context: A System.ComponentModel.TypeDescriptor that provides a format context. You can use this object 

    to get additional information about the environment from which this converter is being invoked.

  

   culture: A System.Globalization.CultureInfo that specifies the culture to represent the color.

   value: The object to convert.

   Returns: An System.Object representing the converted value.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: ColorConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts the specified object to another type.

  

   context: A formatter context. Use this object to extract additional information about the environment 

    from which this converter is being invoked. Always check whether this value is null. Also,

    properties on the context object may return null.

  

   culture: A System.Globalization.CultureInfo that specifies the culture to represent the color.

   value: The object to convert.

   destinationType: The type to convert the object to.

   Returns: An System.Object representing the converted value.
  """
  pass
 def GetStandardValues(self,context=None):
  """
  GetStandardValues(self: ColorConverter,context: ITypeDescriptorContext) -> StandardValuesCollection

  

   Retrieves a collection containing a set of standard values for the data type for which this 

    validator is designed. This will return null if the data type does not support a standard set of 

    values.

  

  

   context: A formatter context. Use this object to extract additional information about the environment 

    from which this converter is being invoked. Always check whether this value is null. Also,

    properties on the context object may return null.

  

   Returns: A collection containing null or a standard set of valid values. The default implementation 

    always returns null.
  """
  pass
 def GetStandardValuesSupported(self,context=None):
  """
  GetStandardValuesSupported(self: ColorConverter,context: ITypeDescriptorContext) -> bool

  

   Determines if this object supports a standard set of values that can be chosen from a list.

  

   context: A System.ComponentModel.TypeDescriptor through which additional context can be provided.

   Returns: true if erload:System.Drawing.ColorConverter.GetStandardValues must be called to find a common 

    set of values the object supports; otherwise,false.
  """
  pass



class Path(object):
 """ Performs operations on System.String instances that contain file or directory path information. These operations are performed in a cross-platform manner. """
 @staticmethod
 def ChangeExtension(path,extension):
  """
  ChangeExtension(path: str,extension: str) -> str

  

   Changes the extension of a path string.

  

   path: The path information to modify. The path cannot contain any of the characters defined in 

    System.IO.Path.GetInvalidPathChars.

  

   extension: The new extension (with or without a leading period). Specify null to remove an existing 

    extension from path.

  

   Returns: The modified path information.On Windows-based desktop platforms,if path is null or an empty 

    string (""),the path information is returned unmodified. If extension is null,the returned 

    string contains the specified path with its extension removed. If path has no extension,and 

    extension is not null,the returned path string contains extension appended to the end of path.
  """
  pass
 @staticmethod
 def Combine(*__args):
  """
  Combine(path1: str,path2: str,path3: str,path4: str) -> str

  

   Combines four strings into a path.

  

   path1: The first path to combine.

   path2: The second path to combine.

   path3: The third path to combine.

   path4: The fourth path to combine.

   Returns: The combined paths.

  Combine(*paths: Array[str]) -> str

  

   Combines an array of strings into a path.

  

   paths: An array of parts of the path.

   Returns: The combined paths.

  Combine(path1: str,path2: str) -> str

  

   Combines two strings into a path.

  

   path1: The first path to combine.

   path2: The second path to combine.

   Returns: The combined paths. If one of the specified paths is a zero-length string,this method returns 

    the other path. If path2 contains an absolute path,this method returns path2.

  

  Combine(path1: str,path2: str,path3: str) -> str

  

   Combines three strings into a path.

  

   path1: The first path to combine.

   path2: The second path to combine.

   path3: The third path to combine.

   Returns: The combined paths.
  """
  pass
 @staticmethod
 def GetDirectoryName(path):
  """
  GetDirectoryName(path: str) -> str

  

   Returns the directory information for the specified path string.

  

   path: The path of a file or directory.

   Returns: Directory information for path,or null if path denotes a root directory or is null. Returns 

    System.String.Empty if path does not contain directory information.
  """
  pass
 @staticmethod
 def GetExtension(path):
  """
  GetExtension(path: str) -> str

  

   Returns the extension of the specified path string.

  

   path: The path string from which to get the extension.

   Returns: The extension of the specified path (including the period "."),or null,or System.String.Empty. 

    If path is null,System.IO.Path.GetExtension(System.String) returns null. If path does not have 

    extension information,System.IO.Path.GetExtension(System.String) returns System.String.Empty.
  """
  pass
 @staticmethod
 def GetFileName(path):
  """
  GetFileName(path: str) -> str

  

   Returns the file name and extension of the specified path string.

  

   path: The path string from which to obtain the file name and extension.

   Returns: The characters after the last directory character in path. If the last character of path is a 

    directory or volume separator character,this method returns System.String.Empty. If path is 

    null,this method returns null.
  """
  pass
 @staticmethod
 def GetFileNameWithoutExtension(path):
  """
  GetFileNameWithoutExtension(path: str) -> str

  

   Returns the file name of the specified path string without the extension.

  

   path: The path of the file.

   Returns: The string returned by System.IO.Path.GetFileName(System.String),minus the last period (.) and 

    all characters following it.
  """
  pass
 @staticmethod
 def GetFullPath(path):
  """
  GetFullPath(path: str) -> str

  

   Returns the absolute path for the specified path string.

  

   path: The file or directory for which to obtain absolute path information.

   Returns: The fully qualified location of path,such as "C:\MyFile.txt".
  """
  pass
 @staticmethod
 def GetInvalidFileNameChars():
  """
  GetInvalidFileNameChars() -> Array[Char]

  

   Gets an array containing the characters that are not allowed in file names.

   Returns: An array containing the characters that are not allowed in file names.
  """
  pass
 @staticmethod
 def GetInvalidPathChars():
  """
  GetInvalidPathChars() -> Array[Char]

  

   Gets an array containing the characters that are not allowed in path names.

   Returns: An array containing the characters that are not allowed in path names.
  """
  pass
 @staticmethod
 def GetPathRoot(path):
  """
  GetPathRoot(path: str) -> str

  

   Gets the root directory information of the specified path.

  

   path: The path from which to obtain root directory information.

   Returns: The root directory of path,such as "C:\",or null if path is null,or an empty string if path 

    does not contain root directory information.
  """
  pass
 @staticmethod
 def GetRandomFileName():
  """
  GetRandomFileName() -> str

  

   Returns a random folder name or file name.

   Returns: A random folder name or file name.
  """
  pass
 @staticmethod
 def GetTempFileName():
  """
  GetTempFileName() -> str

  

   Creates a uniquely named,zero-byte temporary file on disk and returns the full path of that 

    file.

  

   Returns: The full path of the temporary file.
  """
  pass
 @staticmethod
 def GetTempPath():
  """
  GetTempPath() -> str

  

   Returns the path of the current user's temporary folder.

   Returns: The path to the temporary folder,ending with a backslash.
  """
  pass
 @staticmethod
 def HasExtension(path):
  """
  HasExtension(path: str) -> bool

  

   Determines whether a path includes a file name extension.

  

   path: The path to search for an extension.

   Returns: true if the characters that follow the last directory separator (\\ or /) or volume separator 

    (:) in the path include a period (.) followed by one or more characters; otherwise,false.
  """
  pass
 @staticmethod
 def IsPathRooted(path):
  """
  IsPathRooted(path: str) -> bool

  

   Gets a value indicating whether the specified path string contains a root.

  

   path: The path to test.

   Returns: true if path contains a root; otherwise,false.
  """
  pass
 AltDirectorySeparatorChar=None
 DirectorySeparatorChar=None
 InvalidPathChars=None
 PathSeparator=None
 VolumeSeparatorChar=None
 __all__=[
  'AltDirectorySeparatorChar',
  'ChangeExtension',
  'Combine',
  'DirectorySeparatorChar',
  'GetDirectoryName',
  'GetExtension',
  'GetFileName',
  'GetFileNameWithoutExtension',
  'GetFullPath',
  'GetInvalidFileNameChars',
  'GetInvalidPathChars',
  'GetPathRoot',
  'GetRandomFileName',
  'GetTempFileName',
  'GetTempPath',
  'HasExtension',
  'InvalidPathChars',
  'IsPathRooted',
  'PathSeparator',
  'VolumeSeparatorChar',
 ]




class EventWaitHandleAuditRule(AuditRule):
 """
 Represents a set of access rights to be audited for a user or group. This class cannot be inherited.

 

 EventWaitHandleAuditRule(identity: IdentityReference,eventRights: EventWaitHandleRights,flags: AuditFlags)
 """
 @staticmethod
 def __new__(self,identity,eventRights,flags):
  """ __new__(cls: type,identity: IdentityReference,eventRights: EventWaitHandleRights,flags: AuditFlags) """
  pass
 AccessMask=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the access mask for this rule.



"""

 EventWaitHandleRights=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the access rights affected by the audit rule.



Get: EventWaitHandleRights(self: EventWaitHandleAuditRule) -> EventWaitHandleRights



"""





class DataGridAutoGeneratingColumnEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Controls.DataGrid.AutoGeneratingColumn event.

 

 DataGridAutoGeneratingColumnEventArgs(propertyName: str,propertyType: Type,column: DataGridColumn)
 """
 @staticmethod
 def __new__(self,propertyName,propertyType,column):
  """ __new__(cls: type,propertyName: str,propertyType: Type,column: DataGridColumn) """
  pass
 Cancel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the event should be canceled.



Get: Cancel(self: DataGridAutoGeneratingColumnEventArgs) -> bool



Set: Cancel(self: DataGridAutoGeneratingColumnEventArgs)=value

"""

 Column=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the generated column.



Get: Column(self: DataGridAutoGeneratingColumnEventArgs) -> DataGridColumn



Set: Column(self: DataGridAutoGeneratingColumnEventArgs)=value

"""

 PropertyDescriptor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the descriptor of the property bound to the generated column.



Get: PropertyDescriptor(self: DataGridAutoGeneratingColumnEventArgs) -> object



"""

 PropertyName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the property bound to the generated column.



Get: PropertyName(self: DataGridAutoGeneratingColumnEventArgs) -> str



"""

 PropertyType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type of the property bound to the generated column.



Get: PropertyType(self: DataGridAutoGeneratingColumnEventArgs) -> Type



"""





class DataGridCellInfo(object):
 """
 Represents information about a specific cell in a System.Windows.Controls.DataGrid.

 

 DataGridCellInfo(item: object,column: DataGridColumn)

 DataGridCellInfo(cell: DataGridCell)
 """
 def Equals(self,obj):
  """
  Equals(self: DataGridCellInfo,obj: object) -> bool

  

   Indicates whether the specified object is equal to the current instance.

  

   obj: The object to compare to the current instance.

   Returns: true if the comparison object represents the same cell; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DataGridCellInfo) -> int

  

   Returns a hash code for the current System.Windows.Controls.DataGridCellInfo structure.

   Returns: A hash code for the structure.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,item: object,column: DataGridColumn)

  __new__(cls: type,cell: DataGridCell)

  __new__[DataGridCellInfo]() -> DataGridCellInfo
  """
  pass
 def __ne__(self,*args):
  pass
 Column=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the column that contains the cell.



Get: Column(self: DataGridCellInfo) -> DataGridColumn



"""

 IsValid=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the structure holds valid information.



Get: IsValid(self: DataGridCellInfo) -> bool



"""

 Item=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the data item for the row that contains the cell.



Get: Item(self: DataGridCellInfo) -> object



"""





class Padding(object):
 """
 Represents padding or margin information associated with a user interface (UI) element.

 

 Padding(all: int)

 Padding(left: int,top: int,right: int,bottom: int)
 """
 @staticmethod
 def Add(p1,p2):
  """
  Add(p1: Padding,p2: Padding) -> Padding

  

   Computes the sum of the two specified System.Windows.Forms.Padding values.

  

   p1: A System.Windows.Forms.Padding.

   p2: A System.Windows.Forms.Padding.

   Returns: A System.Windows.Forms.Padding that contains the sum of the two specified 

    System.Windows.Forms.Padding values.
  """
  pass
 def Equals(self,other):
  """
  Equals(self: Padding,other: object) -> bool

  

   Determines whether the value of the specified object is equivalent to the current 

    System.Windows.Forms.Padding.

  

  

   other: The object to compare to the current System.Windows.Forms.Padding.

   Returns: true if the System.Windows.Forms.Padding objects are equivalent; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Padding) -> int

  

   Generates a hash code for the current System.Windows.Forms.Padding.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 @staticmethod
 def Subtract(p1,p2):
  """
  Subtract(p1: Padding,p2: Padding) -> Padding

  

   Subtracts one specified System.Windows.Forms.Padding value from another.

  

   p1: A System.Windows.Forms.Padding.

   p2: A System.Windows.Forms.Padding.

   Returns: A System.Windows.Forms.Padding that contains the result of the subtraction of one specified 

    System.Windows.Forms.Padding value from another.
  """
  pass
 def ToString(self):
  """
  ToString(self: Padding) -> str

  

   Returns a string that represents the current System.Windows.Forms.Padding.

   Returns: A System.String that represents the current System.Windows.Forms.Padding.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,all: int)

  __new__(cls: type,left: int,top: int,right: int,bottom: int)

  __new__[Padding]() -> Padding
  """
  pass
 def __ne__(self,*args):
  pass
 def __radd__(self,*args):
  """
  __radd__(p1: Padding,p2: Padding) -> Padding

  

   Performs vector addition on the two specified System.Windows.Forms.Padding objects,resulting in 

    a new System.Windows.Forms.Padding.

  

  

   p1: The first System.Windows.Forms.Padding to add.

   p2: The second System.Windows.Forms.Padding to add.

   Returns: A new System.Windows.Forms.Padding that results from adding p1 and p2.
  """
  pass
 def __rsub__(self,*args):
  """
  __rsub__(p1: Padding,p2: Padding) -> Padding

  

   Performs vector subtraction on the two specified System.Windows.Forms.Padding objects,resulting 

    in a new System.Windows.Forms.Padding.

  

  

   p1: The System.Windows.Forms.Padding to subtract from (the minuend).

   p2: The System.Windows.Forms.Padding to subtract from (the subtrahend).

   Returns: The System.Windows.Forms.Padding result of subtracting p2 from p1.
  """
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-y """
  pass
 All=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the padding value for all the edges.



Get: All(self: Padding) -> int



Set: All(self: Padding)=value

"""

 Bottom=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the padding value for the bottom edge.



Get: Bottom(self: Padding) -> int



Set: Bottom(self: Padding)=value

"""

 Horizontal=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the combined padding for the right and left edges.



Get: Horizontal(self: Padding) -> int



"""

 Left=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the padding value for the left edge.



Get: Left(self: Padding) -> int



Set: Left(self: Padding)=value

"""

 Right=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the padding value for the right edge.



Get: Right(self: Padding) -> int



Set: Right(self: Padding)=value

"""

 Size=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the padding information in the form of a System.Drawing.Size.



Get: Size(self: Padding) -> Size



"""

 Top=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the padding value for the top edge.



Get: Top(self: Padding) -> int



Set: Top(self: Padding)=value

"""

 Vertical=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the combined padding for the top and bottom edges.



Get: Vertical(self: Padding) -> int



"""


 Empty=None




class DataGridCellClipboardEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Controls.DataGridColumn.CopyingCellClipboardContent and System.Windows.Controls.DataGridColumn.PastingCellClipboardContent events.

 

 DataGridCellClipboardEventArgs(item: object,column: DataGridColumn,content: object)
 """
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 @staticmethod
 def __new__(self,item,column,content):
  """ __new__(cls: type,item: object,column: DataGridColumn,content: object) """
  pass
 Column=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the column that contains the cell for which the event occurred.



Get: Column(self: DataGridCellClipboardEventArgs) -> DataGridColumn



"""

 Content=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text value of the cell for which the event occurred.



Get: Content(self: DataGridCellClipboardEventArgs) -> object



Set: Content(self: DataGridCellClipboardEventArgs)=value

"""

 Item=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the data item for the row that contains the cell for which the event occurred.



Get: Item(self: DataGridCellClipboardEventArgs) -> object



"""





# encoding: utf-8
# module System.Net.Mail calls itself Mail
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class AttachmentBase(object,IDisposable):
 """ Base class that represents an email attachment. Classes System.Net.Mail.Attachment,System.Net.Mail.AlternateView,and System.Net.Mail.LinkedResource derive from this class. """
 def Dispose(self):
  """
  Dispose(self: AttachmentBase)

   Releases the resources used by the System.Net.Mail.AttachmentBase.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,fileName: str,mediaType: str)

  __new__(cls: type,fileName: str,contentType: ContentType)

  __new__(cls: type,contentStream: Stream)

  __new__(cls: type,contentStream: Stream,mediaType: str)

  __new__(cls: type,contentStream: Stream,contentType: ContentType)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 ContentId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the MIME content ID for this attachment.



Get: ContentId(self: AttachmentBase) -> str



Set: ContentId(self: AttachmentBase)=value

"""

 ContentStream=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the content stream of this attachment.



Get: ContentStream(self: AttachmentBase) -> Stream



"""

 ContentType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the content type of this attachment.



Get: ContentType(self: AttachmentBase) -> ContentType



Set: ContentType(self: AttachmentBase)=value

"""

 TransferEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the encoding of this attachment.



Get: TransferEncoding(self: AttachmentBase) -> TransferEncoding



Set: TransferEncoding(self: AttachmentBase)=value

"""



class AlternateView(AttachmentBase,IDisposable):
 """
 Represents the format to view an email message.

 

 AlternateView(fileName: str)

 AlternateView(fileName: str,mediaType: str)

 AlternateView(fileName: str,contentType: ContentType)

 AlternateView(contentStream: Stream)

 AlternateView(contentStream: Stream,mediaType: str)

 AlternateView(contentStream: Stream,contentType: ContentType)
 """
 @staticmethod
 def CreateAlternateViewFromString(content,*__args):
  """
  CreateAlternateViewFromString(content: str,contentType: ContentType) -> AlternateView

  

   Creates an System.Net.Mail.AlternateView of an email message using the content specified in a 

    System.String and the specified MIME media type of the content.

  

  

   content: A System.String that contains the content for this attachment.

   contentType: A System.Net.Mime.ContentType that describes the data in string.

   Returns: An System.Net.Mail.AlternateView object that represents an alternate view of an email message.

  CreateAlternateViewFromString(content: str,contentEncoding: Encoding,mediaType: str) -> AlternateView

  

   Creates an System.Net.Mail.AlternateView of an email message using the content specified in a 

    System.String,the specified text encoding,and MIME media type of the content.

  

  

   content: A System.String that contains the content for this attachment.

   contentEncoding: An System.Text.Encoding. This value can be null.

   mediaType: The MIME media type of the content.

   Returns: An System.Net.Mail.AlternateView object that represents an alternate view of an email message.

  CreateAlternateViewFromString(content: str) -> AlternateView

  

   Creates a System.Net.Mail.AlternateView of an email message using the content specified in a 

    System.String.

  

  

   content: The System.String that contains the content of the email message.

   Returns: An System.Net.Mail.AlternateView object that represents an alternate view of an email message.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: AlternateView,disposing: bool)

   Releases the unmanaged resources used by the System.Net.Mail.AlternateView and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,fileName: str,mediaType: str)

  __new__(cls: type,fileName: str,contentType: ContentType)

  __new__(cls: type,contentStream: Stream)

  __new__(cls: type,contentStream: Stream,mediaType: str)

  __new__(cls: type,contentStream: Stream,contentType: ContentType)
  """
  pass
 BaseUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the Base URI to use for resolving relative URIs in the System.Net.Mail.AlternateView.



Get: BaseUri(self: AlternateView) -> Uri



Set: BaseUri(self: AlternateView)=value

"""

 LinkedResources=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the set of embedded resources referred to by this attachment.



Get: LinkedResources(self: AlternateView) -> LinkedResourceCollection



"""



class AlternateViewCollection(Collection[AlternateView],IList[AlternateView],ICollection[AlternateView],IEnumerable[AlternateView],IEnumerable,IList,ICollection,IReadOnlyList[AlternateView],IReadOnlyCollection[AlternateView],IDisposable):
 """ Represents a collection of System.Net.Mail.AlternateView objects. """
 def ClearItems(self,*args):
  """ ClearItems(self: AlternateViewCollection) """
  pass
 def Dispose(self):
  """
  Dispose(self: AlternateViewCollection)

   Releases all resources used by the System.Net.Mail.AlternateViewCollection.
  """
  pass
 def InsertItem(self,*args):
  """ InsertItem(self: AlternateViewCollection,index: int,item: AlternateView) """
  pass
 def RemoveItem(self,*args):
  """ RemoveItem(self: AlternateViewCollection,index: int) """
  pass
 def SetItem(self,*args):
  """ SetItem(self: AlternateViewCollection,index: int,item: AlternateView) """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""



class Attachment(AttachmentBase,IDisposable):
 """
 Represents an attachment to an e-mail.

 

 Attachment(fileName: str)

 Attachment(fileName: str,mediaType: str)

 Attachment(fileName: str,contentType: ContentType)

 Attachment(contentStream: Stream,name: str)

 Attachment(contentStream: Stream,name: str,mediaType: str)

 Attachment(contentStream: Stream,contentType: ContentType)
 """
 @staticmethod
 def CreateAttachmentFromString(content,*__args):
  """
  CreateAttachmentFromString(content: str,contentType: ContentType) -> Attachment

  

   Creates a mail attachment using the content from the specified string,and the specified 

    System.Net.Mime.ContentType.

  

  

   content: A System.String that contains the content for this attachment.

   contentType: A System.Net.Mime.ContentType object that represents the Multipurpose Internet Mail Exchange 

    (MIME) protocol Content-Type header to be used.

  

   Returns: An object of type System.Net.Mail.Attachment.

  CreateAttachmentFromString(content: str,name: str,contentEncoding: Encoding,mediaType: str) -> Attachment

  

   Creates a mail attachment using the content from the specified string,the specified MIME 

    content type name,character encoding,and MIME header information for the attachment.

  

  

   content: A System.String that contains the content for this attachment.

   name: The MIME content type name value in the content type associated with this attachment.

   contentEncoding: An System.Text.Encoding. This value can be null.

   mediaType: A System.String that contains the MIME Content-Header information for this attachment. This 

    value can be null.

  

   Returns: An object of type System.Net.Mail.Attachment.

  CreateAttachmentFromString(content: str,name: str) -> Attachment

  

   Creates a mail attachment using the content from the specified string,and the specified MIME 

    content type name.

  

  

   content: A System.String that contains the content for this attachment.

   name: The MIME content type name value in the content type associated with this attachment.

   Returns: An object of type System.Net.Mail.Attachment.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: AttachmentBase,disposing: bool)

   Releases the unmanaged resources used by the System.Net.Mail.AttachmentBase and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,fileName: str,mediaType: str)

  __new__(cls: type,fileName: str,contentType: ContentType)

  __new__(cls: type,contentStream: Stream,name: str)

  __new__(cls: type,contentStream: Stream,name: str,mediaType: str)

  __new__(cls: type,contentStream: Stream,contentType: ContentType)
  """
  pass
 ContentDisposition=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the MIME content disposition for this attachment.



Get: ContentDisposition(self: Attachment) -> ContentDisposition



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the MIME content type name value in the content type associated with this attachment.



Get: Name(self: Attachment) -> str



Set: Name(self: Attachment)=value

"""

 NameEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Specifies the encoding for the System.Net.Mail.AttachmentSystem.Net.Mail.Attachment.Name.



Get: NameEncoding(self: Attachment) -> Encoding



Set: NameEncoding(self: Attachment)=value

"""



class AttachmentCollection(Collection[Attachment],IList[Attachment],ICollection[Attachment],IEnumerable[Attachment],IEnumerable,IList,ICollection,IReadOnlyList[Attachment],IReadOnlyCollection[Attachment],IDisposable):
 """ Stores attachments to be sent as part of an e-mail message. """
 def ClearItems(self,*args):
  """ ClearItems(self: AttachmentCollection) """
  pass
 def Dispose(self):
  """
  Dispose(self: AttachmentCollection)

   Releases all resources used by the System.Net.Mail.AttachmentCollection.
  """
  pass
 def InsertItem(self,*args):
  """ InsertItem(self: AttachmentCollection,index: int,item: Attachment) """
  pass
 def RemoveItem(self,*args):
  """ RemoveItem(self: AttachmentCollection,index: int) """
  pass
 def SetItem(self,*args):
  """ SetItem(self: AttachmentCollection,index: int,item: Attachment) """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""



class DeliveryNotificationOptions(Enum,IComparable,IFormattable,IConvertible):
 """
 Describes the delivery notification options for e-mail.

 

 enum (flags) DeliveryNotificationOptions,values: Delay (4),Never (134217728),None (0),OnFailure (2),OnSuccess (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Delay=None
 Never=None
 None=None
 OnFailure=None
 OnSuccess=None
 value__=None


class LinkedResource(AttachmentBase,IDisposable):
 """
 Represents an embedded external resource in an email attachment,such as an image in an HTML attachment.

 

 LinkedResource(fileName: str)

 LinkedResource(fileName: str,mediaType: str)

 LinkedResource(fileName: str,contentType: ContentType)

 LinkedResource(contentStream: Stream)

 LinkedResource(contentStream: Stream,mediaType: str)

 LinkedResource(contentStream: Stream,contentType: ContentType)
 """
 @staticmethod
 def CreateLinkedResourceFromString(content,*__args):
  """
  CreateLinkedResourceFromString(content: str,contentType: ContentType) -> LinkedResource

  

   Creates a System.Net.Mail.LinkedResource object from a string to be included in an email 

    attachment as an embedded resource,with the specified content type,and media type as plain 

    text.

  

  

   content: A string that contains the embedded resource to be included in the email attachment.

   contentType: The type of the content.

   Returns: A System.Net.Mail.LinkedResource object that contains the embedded resource to be included in 

    the email attachment.

  

  CreateLinkedResourceFromString(content: str,contentEncoding: Encoding,mediaType: str) -> LinkedResource

  

   Creates a System.Net.Mail.LinkedResource object from a string to be included in an email 

    attachment as an embedded resource,with the specified content type,and media type.

  

  

   content: A string that contains the embedded resource to be included in the email attachment.

   contentEncoding: The type of the content.

   mediaType: The MIME media type of the content.

   Returns: A System.Net.Mail.LinkedResource object that contains the embedded resource to be included in 

    the email attachment.

  

  CreateLinkedResourceFromString(content: str) -> LinkedResource

  

   Creates a System.Net.Mail.LinkedResource object from a string to be included in an email 

    attachment as an embedded resource. The default media type is plain text,and the default 

    content type is ASCII.

  

  

   content: A string that contains the embedded resource to be included in the email attachment.

   Returns: A System.Net.Mail.LinkedResource object that contains the embedded resource to be included in 

    the email attachment.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: AttachmentBase,disposing: bool)

   Releases the unmanaged resources used by the System.Net.Mail.AttachmentBase and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,fileName: str,mediaType: str)

  __new__(cls: type,fileName: str,contentType: ContentType)

  __new__(cls: type,contentStream: Stream)

  __new__(cls: type,contentStream: Stream,mediaType: str)

  __new__(cls: type,contentStream: Stream,contentType: ContentType)
  """
  pass
 ContentLink=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a URI that the resource must match.



Get: ContentLink(self: LinkedResource) -> Uri



Set: ContentLink(self: LinkedResource)=value

"""



class LinkedResourceCollection(Collection[LinkedResource],IList[LinkedResource],ICollection[LinkedResource],IEnumerable[LinkedResource],IEnumerable,IList,ICollection,IReadOnlyList[LinkedResource],IReadOnlyCollection[LinkedResource],IDisposable):
 """ Stores linked resources to be sent as part of an e-mail message. """
 def ClearItems(self,*args):
  """ ClearItems(self: LinkedResourceCollection) """
  pass
 def Dispose(self):
  """
  Dispose(self: LinkedResourceCollection)

   Releases all resources used by the System.Net.Mail.LinkedResourceCollection.
  """
  pass
 def InsertItem(self,*args):
  """ InsertItem(self: LinkedResourceCollection,index: int,item: LinkedResource) """
  pass
 def RemoveItem(self,*args):
  """ RemoveItem(self: LinkedResourceCollection,index: int) """
  pass
 def SetItem(self,*args):
  """ SetItem(self: LinkedResourceCollection,index: int,item: LinkedResource) """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""



class MailAddress(object):
 """
 Represents the address of an electronic mail sender or recipient.

 

 MailAddress(address: str)

 MailAddress(address: str,displayName: str)

 MailAddress(address: str,displayName: str,displayNameEncoding: Encoding)
 """
 def Equals(self,value):
  """
  Equals(self: MailAddress,value: object) -> bool

  

   Compares two mail addresses.

  

   value: A System.Net.Mail.MailAddress instance to compare to the current instance.

   Returns: true if the two mail addresses are equal; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: MailAddress) -> int

  

   Returns a hash value for a mail address.

   Returns: An integer hash value.
  """
  pass
 def ToString(self):
  """
  ToString(self: MailAddress) -> str

  

   Returns a string representation of this instance.

   Returns: A System.String that contains the contents of this System.Net.Mail.MailAddress.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,address,displayName=None,displayNameEncoding=None):
  """
  __new__(cls: type,address: str)

  __new__(cls: type,address: str,displayName: str)

  __new__(cls: type,address: str,displayName: str,displayNameEncoding: Encoding)
  """
  pass
 def __ne__(self,*args):
  pass
 Address=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the e-mail address specified when this instance was created.



Get: Address(self: MailAddress) -> str



"""

 DisplayName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the display name composed from the display name and address information specified when this instance was created.



Get: DisplayName(self: MailAddress) -> str



"""

 Host=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the host portion of the address specified when this instance was created.



Get: Host(self: MailAddress) -> str



"""

 User=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the user information from the address specified when this instance was created.



Get: User(self: MailAddress) -> str



"""



class MailAddressCollection(Collection[MailAddress],IList[MailAddress],ICollection[MailAddress],IEnumerable[MailAddress],IEnumerable,IList,ICollection,IReadOnlyList[MailAddress],IReadOnlyCollection[MailAddress]):
 """
 Store e-mail addresses that are associated with an e-mail message.

 

 MailAddressCollection()
 """
 def Add(self,*__args):
  """
  Add(self: MailAddressCollection,addresses: str)

   Add a list of e-mail addresses to the collection.

  

   addresses: The e-mail addresses to add to the System.Net.Mail.MailAddressCollection. Multiple e-mail 

    addresses must be separated with a comma character (",").
  """
  pass
 def ClearItems(self,*args):
  """
  ClearItems(self: Collection[MailAddress])

   Removes all elements from the System.Collections.ObjectModel.Collection.
  """
  pass
 def InsertItem(self,*args):
  """
  InsertItem(self: MailAddressCollection,index: int,item: MailAddress)

   Inserts an e-mail address into the System.Net.Mail.MailAddressCollection,at the specified 

    location.

  

  

   index: The location at which to insert the e-mail address that is specified by item.

   item: The e-mail address to be inserted into the collection.
  """
  pass
 def RemoveItem(self,*args):
  """
  RemoveItem(self: Collection[MailAddress],index: int)

   Removes the element at the specified index of the System.Collections.ObjectModel.Collection.

  

   index: The zero-based index of the element to remove.
  """
  pass
 def SetItem(self,*args):
  """
  SetItem(self: MailAddressCollection,index: int,item: MailAddress)

   Replaces the element at the specified index.

  

   index: The index of the e-mail address element to be replaced.

   item: An e-mail address that will replace the element in the collection.
  """
  pass
 def ToString(self):
  """
  ToString(self: MailAddressCollection) -> str

  

   Returns a string representation of the e-mail addresses in this 

    System.Net.Mail.MailAddressCollection object.

  

   Returns: A System.String containing the e-mail addresses in this collection.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 def __str__(self,*args):
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""



class MailMessage(object,IDisposable):
 """
 Represents an e-mail message that can be sent using the System.Net.Mail.SmtpClient class.

 

 MailMessage()

 MailMessage(from: str,to: str)

 MailMessage(from: str,to: str,subject: str,body: str)

 MailMessage(from: MailAddress,to: MailAddress)
 """
 def Dispose(self):
  """
  Dispose(self: MailMessage)

   Releases all resources used by the System.Net.Mail.MailMessage.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,from=None,to=None,subject=None,body=None):
  """
  __new__(cls: type)

  __new__(cls: type,from: str,to: str)

  __new__(cls: type,from: str,to: str,subject: str,body: str)

  __new__(cls: type,from: MailAddress,to: MailAddress)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 AlternateViews=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the attachment collection used to store alternate forms of the message body.



Get: AlternateViews(self: MailMessage) -> AlternateViewCollection



"""

 Attachments=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the attachment collection used to store data attached to this e-mail message.



Get: Attachments(self: MailMessage) -> AttachmentCollection



"""

 Bcc=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the address collection that contains the blind carbon copy (BCC) recipients for this e-mail message.



Get: Bcc(self: MailMessage) -> MailAddressCollection



"""

 Body=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the message body.



Get: Body(self: MailMessage) -> str



Set: Body(self: MailMessage)=value

"""

 BodyEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the encoding used to encode the message body.



Get: BodyEncoding(self: MailMessage) -> Encoding



Set: BodyEncoding(self: MailMessage)=value

"""

 BodyTransferEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: BodyTransferEncoding(self: MailMessage) -> TransferEncoding



Set: BodyTransferEncoding(self: MailMessage)=value

"""

 CC=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the address collection that contains the carbon copy (CC) recipients for this e-mail message.



Get: CC(self: MailMessage) -> MailAddressCollection



"""

 DeliveryNotificationOptions=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the delivery notifications for this e-mail message.



Get: DeliveryNotificationOptions(self: MailMessage) -> DeliveryNotificationOptions



Set: DeliveryNotificationOptions(self: MailMessage)=value

"""

 From=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the from address for this e-mail message.



Get: From(self: MailMessage) -> MailAddress



Set: From(self: MailMessage)=value

"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the e-mail headers that are transmitted with this e-mail message.



Get: Headers(self: MailMessage) -> NameValueCollection



"""

 HeadersEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the encoding used for the user-defined custom headers for this e-mail message.



Get: HeadersEncoding(self: MailMessage) -> Encoding



Set: HeadersEncoding(self: MailMessage)=value

"""

 IsBodyHtml=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the mail message body is in Html.



Get: IsBodyHtml(self: MailMessage) -> bool



Set: IsBodyHtml(self: MailMessage)=value

"""

 Priority=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the priority of this e-mail message.



Get: Priority(self: MailMessage) -> MailPriority



Set: Priority(self: MailMessage)=value

"""

 ReplyTo=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the ReplyTo address for the mail message.



Get: ReplyTo(self: MailMessage) -> MailAddress



Set: ReplyTo(self: MailMessage)=value

"""

 ReplyToList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the list of addresses to reply to for the mail message.



Get: ReplyToList(self: MailMessage) -> MailAddressCollection



"""

 Sender=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the sender's address for this e-mail message.



Get: Sender(self: MailMessage) -> MailAddress



Set: Sender(self: MailMessage)=value

"""

 Subject=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the subject line for this e-mail message.



Get: Subject(self: MailMessage) -> str



Set: Subject(self: MailMessage)=value

"""

 SubjectEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the encoding used for the subject content for this e-mail message.



Get: SubjectEncoding(self: MailMessage) -> Encoding



Set: SubjectEncoding(self: MailMessage)=value

"""

 To=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the address collection that contains the recipients of this e-mail message.



Get: To(self: MailMessage) -> MailAddressCollection



"""



class MailPriority(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the priority of a System.Net.Mail.MailMessage.

 

 enum MailPriority,values: High (2),Low (1),Normal (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 High=None
 Low=None
 Normal=None
 value__=None


class SendCompletedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle the System.Net.Mail.SmtpClient.SendCompleted event.

 

 SendCompletedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: SendCompletedEventHandler,sender: object,e: AsyncCompletedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: SendCompletedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: SendCompletedEventHandler,sender: object,e: AsyncCompletedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class SmtpAccess(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the level of access allowed to a Simple Mail Transport Protocol (SMTP) server.

 

 enum SmtpAccess,values: Connect (1),ConnectToUnrestrictedPort (2),None (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Connect=None
 ConnectToUnrestrictedPort=None
 None=None
 value__=None


class SmtpClient(object,IDisposable):
 """
 Allows applications to send e-mail by using the Simple Mail Transfer Protocol (SMTP).

 

 SmtpClient()

 SmtpClient(host: str)

 SmtpClient(host: str,port: int)
 """
 def Dispose(self):
  """
  Dispose(self: SmtpClient)

   Sends a QUIT message to the SMTP server,gracefully ends the TCP connection,and releases all 

    resources used by the current instance of the System.Net.Mail.SmtpClient class.
  """
  pass
 def OnSendCompleted(self,*args):
  """
  OnSendCompleted(self: SmtpClient,e: AsyncCompletedEventArgs)

   Raises the System.Net.Mail.SmtpClient.SendCompleted event.

  

   e: An System.ComponentModel.AsyncCompletedEventArgs that contains event data.
  """
  pass
 def Send(self,*__args):
  """
  Send(self: SmtpClient,message: MailMessage)

   Sends the specified message to an SMTP server for delivery.

  

   message: A System.Net.Mail.MailMessage that contains the message to send.

  Send(self: SmtpClient,from: str,recipients: str,subject: str,body: str)

   Sends the specified e-mail message to an SMTP server for delivery. The message sender,

    recipients,subject,and message body are specified using System.String objects.

  

  

   from: A System.String that contains the address information of the message sender.

   recipients: A System.String that contains the addresses that the message is sent to.

   subject: A System.String that contains the subject line for the message.

   body: A System.String that contains the message body.
  """
  pass
 def SendAsync(self,*__args):
  """
  SendAsync(self: SmtpClient,message: MailMessage,userToken: object)

   Sends the specified e-mail message to an SMTP server for delivery. This method does not block 

    the calling thread and allows the caller to pass an object to the method that is invoked when 

    the operation completes.

  

  

   message: A System.Net.Mail.MailMessage that contains the message to send.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.

  

  SendAsync(self: SmtpClient,from: str,recipients: str,subject: str,body: str,userToken: object)

   Sends an e-mail message to an SMTP server for delivery. The message sender,recipients,subject,

    and message body are specified using System.String objects. This method does not block the 

    calling thread and allows the caller to pass an object to the method that is invoked when the 

    operation completes.

  

  

   from: A System.String that contains the address information of the message sender.

   recipients: A System.String that contains the address that the message is sent to.

   subject: A System.String that contains the subject line for the message.

   body: A System.String that contains the message body.

   userToken: A user-defined object that is passed to the method invoked when the asynchronous operation 

    completes.
  """
  pass
 def SendAsyncCancel(self):
  """
  SendAsyncCancel(self: SmtpClient)

   Cancels an asynchronous operation to send an e-mail message.
  """
  pass
 def SendMailAsync(self,*__args):
  """
  SendMailAsync(self: SmtpClient,message: MailMessage) -> Task

  SendMailAsync(self: SmtpClient,from: str,recipients: str,subject: str,body: str) -> Task
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,host=None,port=None):
  """
  __new__(cls: type)

  __new__(cls: type,host: str)

  __new__(cls: type,host: str,port: int)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 ClientCertificates=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Specify which certificates should be used to establish the Secure Sockets Layer (SSL) connection.



Get: ClientCertificates(self: SmtpClient) -> X509CertificateCollection



"""

 Credentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the credentials used to authenticate the sender.



Get: Credentials(self: SmtpClient) -> ICredentialsByHost



Set: Credentials(self: SmtpClient)=value

"""

 DeliveryFormat=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: DeliveryFormat(self: SmtpClient) -> SmtpDeliveryFormat



Set: DeliveryFormat(self: SmtpClient)=value

"""

 DeliveryMethod=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Specifies how outgoing email messages will be handled.



Get: DeliveryMethod(self: SmtpClient) -> SmtpDeliveryMethod



Set: DeliveryMethod(self: SmtpClient)=value

"""

 EnableSsl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Specify whether the System.Net.Mail.SmtpClient uses Secure Sockets Layer (SSL) to encrypt the connection.



Get: EnableSsl(self: SmtpClient) -> bool



Set: EnableSsl(self: SmtpClient)=value

"""

 Host=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name or IP address of the host used for SMTP transactions.



Get: Host(self: SmtpClient) -> str



Set: Host(self: SmtpClient)=value

"""

 PickupDirectoryLocation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the folder where applications save mail messages to be processed by the local SMTP server.



Get: PickupDirectoryLocation(self: SmtpClient) -> str



Set: PickupDirectoryLocation(self: SmtpClient)=value

"""

 Port=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the port used for SMTP transactions.



Get: Port(self: SmtpClient) -> int



Set: Port(self: SmtpClient)=value

"""

 ServicePoint=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the network connection used to transmit the e-mail message.



Get: ServicePoint(self: SmtpClient) -> ServicePoint



"""

 TargetName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the Service Provider Name (SPN) to use for authentication when using extended protection.



Get: TargetName(self: SmtpClient) -> str



Set: TargetName(self: SmtpClient)=value

"""

 Timeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that specifies the amount of time after which a synchronous erload:System.Net.Mail.SmtpClient.Send call times out.



Get: Timeout(self: SmtpClient) -> int



Set: Timeout(self: SmtpClient)=value

"""

 UseDefaultCredentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a System.Boolean value that controls whether the System.Net.CredentialCache.DefaultCredentials are sent with requests.



Get: UseDefaultCredentials(self: SmtpClient) -> bool



Set: UseDefaultCredentials(self: SmtpClient)=value

"""


 SendCompleted=None


class SmtpDeliveryFormat(Enum,IComparable,IFormattable,IConvertible):
 """ enum SmtpDeliveryFormat,values: International (1),SevenBit (0) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 International=None
 SevenBit=None
 value__=None


class SmtpDeliveryMethod(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how email messages are delivered.

 

 enum SmtpDeliveryMethod,values: Network (0),PickupDirectoryFromIis (2),SpecifiedPickupDirectory (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Network=None
 PickupDirectoryFromIis=None
 SpecifiedPickupDirectory=None
 value__=None


class SmtpException(Exception,ISerializable,_Exception):
 """
 Represents the exception that is thrown when the System.Net.Mail.SmtpClient is not able to complete a erload:System.Net.Mail.SmtpClient.Send or erload:System.Net.Mail.SmtpClient.SendAsync operation.

 

 SmtpException(statusCode: SmtpStatusCode)

 SmtpException(statusCode: SmtpStatusCode,message: str)

 SmtpException()

 SmtpException(message: str)

 SmtpException(message: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,serializationInfo,streamingContext):
  """
  GetObjectData(self: SmtpException,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo instance with the data needed to 

    serialize the System.Net.Mail.SmtpException.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to populate with data.

   streamingContext: A System.Runtime.Serialization.StreamingContext that specifies the destination for this 

    serialization.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,statusCode: SmtpStatusCode)

  __new__(cls: type,statusCode: SmtpStatusCode,message: str)

  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)

  __new__(cls: type,serializationInfo: SerializationInfo,streamingContext: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 StatusCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the status code returned by an SMTP server when an e-mail message is transmitted.



Get: StatusCode(self: SmtpException) -> SmtpStatusCode



Set: StatusCode(self: SmtpException)=value

"""



class SmtpFailedRecipientException(SmtpException,ISerializable,_Exception):
 """
 Represents the exception that is thrown when the System.Net.Mail.SmtpClient is not able to complete a erload:System.Net.Mail.SmtpClient.Send or erload:System.Net.Mail.SmtpClient.SendAsync operation to a particular recipient.

 

 SmtpFailedRecipientException()

 SmtpFailedRecipientException(message: str)

 SmtpFailedRecipientException(message: str,innerException: Exception)

 SmtpFailedRecipientException(statusCode: SmtpStatusCode,failedRecipient: str)

 SmtpFailedRecipientException(statusCode: SmtpStatusCode,failedRecipient: str,serverResponse: str)

 SmtpFailedRecipientException(message: str,failedRecipient: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,serializationInfo,streamingContext):
  """
  GetObjectData(self: SmtpFailedRecipientException,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo instance with the data that is needed 

    to serialize the System.Net.Mail.SmtpFailedRecipientException.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to populate with data.

   streamingContext: A System.Runtime.Serialization.StreamingContext that specifies the destination for this 

    serialization.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)

  __new__(cls: type,statusCode: SmtpStatusCode,failedRecipient: str)

  __new__(cls: type,statusCode: SmtpStatusCode,failedRecipient: str,serverResponse: str)

  __new__(cls: type,message: str,failedRecipient: str,innerException: Exception)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 FailedRecipient=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Indicates the e-mail address with delivery difficulties.



Get: FailedRecipient(self: SmtpFailedRecipientException) -> str



"""



class SmtpFailedRecipientsException(SmtpFailedRecipientException,ISerializable,_Exception):
 """
 The exception that is thrown when e-mail is sent using an System.Net.Mail.SmtpClient and cannot be delivered to all recipients.

 

 SmtpFailedRecipientsException()

 SmtpFailedRecipientsException(message: str)

 SmtpFailedRecipientsException(message: str,innerException: Exception)

 SmtpFailedRecipientsException(message: str,innerExceptions: Array[SmtpFailedRecipientException])
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,serializationInfo,streamingContext):
  """
  GetObjectData(self: SmtpFailedRecipientsException,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo instance with the data that is needed 

    to serialize the System.Net.Mail.SmtpFailedRecipientsException.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to be used.

   streamingContext: The System.Runtime.Serialization.StreamingContext to be used.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)

  __new__(cls: type,message: str,innerExceptions: Array[SmtpFailedRecipientException])
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 InnerExceptions=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets one or more System.Net.Mail.SmtpFailedRecipientExceptions that indicate the e-mail recipients with SMTP delivery errors.



Get: InnerExceptions(self: SmtpFailedRecipientsException) -> Array[SmtpFailedRecipientException]



"""



class SmtpPermission(CodeAccessPermission,IPermission,ISecurityEncodable,IStackWalk,IUnrestrictedPermission):
 """
 Controls access to Simple Mail Transport Protocol (SMTP) servers.

 

 SmtpPermission(state: PermissionState)

 SmtpPermission(unrestricted: bool)

 SmtpPermission(access: SmtpAccess)
 """
 def AddPermission(self,access):
  """
  AddPermission(self: SmtpPermission,access: SmtpAccess)

   Adds the specified access level value to the permission.

  

   access: One of the System.Net.Mail.SmtpAccess values.
  """
  pass
 def Copy(self):
  """
  Copy(self: SmtpPermission) -> IPermission

  

   Creates and returns an identical copy of the current permission.

   Returns: An System.Net.Mail.SmtpPermission that is identical to the current permission.
  """
  pass
 def FromXml(self,securityElement):
  """
  FromXml(self: SmtpPermission,securityElement: SecurityElement)

   Sets the state of the permission using the specified XML encoding.

  

   securityElement: The XML encoding to use to set the state of the current permission.
  """
  pass
 def Intersect(self,target):
  """
  Intersect(self: SmtpPermission,target: IPermission) -> IPermission

  

   Creates and returns a permission that is the intersection of the current permission and the 

    specified permission.

  

  

   target: An System.Security.IPermission to intersect with the current permission. It must be of the same 

    type as the current permission.

  

   Returns: An System.Net.Mail.SmtpPermission that represents the intersection of the current permission and 

    the specified permission. Returns null if the intersection is empty or target is null.
  """
  pass
 def IsSubsetOf(self,target):
  """
  IsSubsetOf(self: SmtpPermission,target: IPermission) -> bool

  

   Returns a value indicating whether the current permission is a subset of the specified 

    permission.

  

  

   target: An System.Security.IPermission that is to be tested for the subset relationship. This permission 

    must be of the same type as the current permission.

  

   Returns: true if the current permission is a subset of the specified permission; otherwise,false.
  """
  pass
 def IsUnrestricted(self):
  """
  IsUnrestricted(self: SmtpPermission) -> bool

  

   Returns a value indicating whether the current permission is unrestricted.

   Returns: true if the current permission is unrestricted; otherwise,false.
  """
  pass
 def ToXml(self):
  """
  ToXml(self: SmtpPermission) -> SecurityElement

  

   Creates an XML encoding of the state of the permission.

   Returns: A System.Security.SecurityElement that contains an XML encoding of the current permission.
  """
  pass
 def Union(self,target):
  """
  Union(self: SmtpPermission,target: IPermission) -> IPermission

  

   Creates a permission that is the union of the current permission and the specified permission.

  

   target: An System.Security.IPermission to combine with the current permission.

   Returns: A new System.Net.Mail.SmtpPermission permission that represents the union of the current 

    permission and the specified permission.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,state: PermissionState)

  __new__(cls: type,unrestricted: bool)

  __new__(cls: type,access: SmtpAccess)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Access=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the level of access to SMTP servers controlled by the permission.



Get: Access(self: SmtpPermission) -> SmtpAccess



"""



class SmtpPermissionAttribute(CodeAccessSecurityAttribute,_Attribute):
 """
 Controls access to Simple Mail Transport Protocol (SMTP) servers.

 

 SmtpPermissionAttribute(action: SecurityAction)
 """
 def CreatePermission(self):
  """
  CreatePermission(self: SmtpPermissionAttribute) -> IPermission

  

   Creates a permission object that can be stored with the 

    System.Security.Permissions.SecurityAction in an assembly's metadata.

  

   Returns: An System.Net.Mail.SmtpPermission instance.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,action):
  """ __new__(cls: type,action: SecurityAction) """
  pass
 def __reduce_ex__(self,*args):
  pass
 Access=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the level of access to SMTP servers controlled by the attribute.



Get: Access(self: SmtpPermissionAttribute) -> str



Set: Access(self: SmtpPermissionAttribute)=value

"""



class SmtpStatusCode(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the outcome of sending e-mail by using the System.Net.Mail.SmtpClient class.

 

 enum SmtpStatusCode,values: BadCommandSequence (503),CannotVerifyUserWillAttemptDelivery (252),ClientNotPermitted (454),CommandNotImplemented (502),CommandParameterNotImplemented (504),CommandUnrecognized (500),ExceededStorageAllocation (552),GeneralFailure (-1),HelpMessage (214),InsufficientStorage (452),LocalErrorInProcessing (451),MailboxBusy (450),MailboxNameNotAllowed (553),MailboxUnavailable (550),MustIssueStartTlsFirst (530),Ok (250),ServiceClosingTransmissionChannel (221),ServiceNotAvailable (421),ServiceReady (220),StartMailInput (354),SyntaxError (501),SystemStatus (211),TransactionFailed (554),UserNotLocalTryAlternatePath (551),UserNotLocalWillForward (251)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 BadCommandSequence=None
 CannotVerifyUserWillAttemptDelivery=None
 ClientNotPermitted=None
 CommandNotImplemented=None
 CommandParameterNotImplemented=None
 CommandUnrecognized=None
 ExceededStorageAllocation=None
 GeneralFailure=None
 HelpMessage=None
 InsufficientStorage=None
 LocalErrorInProcessing=None
 MailboxBusy=None
 MailboxNameNotAllowed=None
 MailboxUnavailable=None
 MustIssueStartTlsFirst=None
 Ok=None
 ServiceClosingTransmissionChannel=None
 ServiceNotAvailable=None
 ServiceReady=None
 StartMailInput=None
 SyntaxError=None
 SystemStatus=None
 TransactionFailed=None
 UserNotLocalTryAlternatePath=None
 UserNotLocalWillForward=None
 value__=None


